{% extends "base.html.twig" %}

{% block title %}{{ 'dmarc.summary.title'|trans({'domain': domain}) }}{% endblock %}

{% block body %}

<ul class="nav nav-tabs" style="margin-bottom: 1em;">
    <li role="presentation" class="active"><a href="{{ path('dmarc_domain_summary', {name: domain})  }}">{{ 'dmarc.summary.label'|trans }}</a></li>
    <li role="presentation"><a href="{{ path('dmarc_domain', {name: domain})  }}">{{ 'dmarc.reports.label'|trans }}</a></li>
</ul>

{% if feedback.count == 0 %}
    <em>{{ 'dmarc.no_reports'|trans }}</em>
{% else %}
{% if feedback.simpleRecords is not empty %}
    <table class="data">
        <thead>
        <tr>
            <th class="count" rowspan="2">{{ 'dmarc.count'|trans }}</th>
            <th class="ip" rowspan="2">{{ 'dmarc.ip'|trans }}</th>
            <th class="source" rowspan="2">{{ 'dmarc.reported_by'|trans }}</th>
            <td colspan="3" class="policy-evaluation">{{ 'dmarc.policy_evaluation'|trans }}</td>
        </tr>
        <tr>
            <th class="disposition">{{ 'dmarc.disposition'|trans }}</th>
            <th class="policy">{{ 'dmarc.dkim'|trans }}</th>
            <th class="policy">{{ 'dmarc.spf'|trans }}</th>
        </tr>
        </thead>
        <tbody>
        {% for record in feedback.simpleRecords %}
            <tr data-auth-results="<table><thead><tr><th colspan='3'>{{ 'dmarc.auth_results'|trans }}</th></tr></thead><tbody>
            {%- for dkim in record.dkimAuthResults -%}
            <tr><td class='auth-type'>DKIM</td><td class='auth-domain'><strong>{{ dkim.domain }}</strong> {% if dkim.selector is not empty %}({{ dkim.selector }}){% endif %}</td><td class='auth-{{ dkim.result }}'>{{ dkim.result }}</td></tr>
            {%- endfor -%}
            {%- for spf in record.spfAuthResults -%}
            <tr><td class='auth-type'>SPF</td><td class='auth-domain'><strong>{{ spf.domain }}</strong></td><td class='auth-{{ spf.result }}'>{{ spf.result }}</td></tr>
            {%- endfor -%}
            </table>">
                <td class="count">{{ record.count|format_number }}</td>
                <th>{{ record.sourceIp|rich_ip(null, false, false) }}</th>
                <td style="color: gray">{{ record.reporters|join(', ') }}</td>
                <td class="disposition">{{ record.dispositions|join(', ') }}</td>
                <td class="policy-{{ record.dkim }}">
                    {% if record.dkim == 'fail' %}
                        <strong><i class="fa fa-exclamation-triangle"></i> {{ record.dkim }}</strong>
                    {% else %}
                        {{ record.dkim }}
                    {% endif %}

                </td>
                <td class="policy-{{ record.spf }}">
                    {% if record.spf == 'fail' %}
                        <strong><i class="fa fa-exclamation-triangle"></i> {{ record.spf }}</strong>
                    {% else %}
                        {{ record.spf }}
                    {% endif %}
                </td>
            </tr>
        {% endfor %}
        </tbody>
    </table>
    {% endif %}

    {% if feedback.overriddenRecords is not empty %}
    <h3>{{ 'dmarc.overriden_policy_records'|trans }}</h3>

    <table class="data">
        <thead>
        <tr>
            <th class="count" rowspan="2">{{ 'dmarc.count'|trans }}</th>
            <th class="ip" rowspan="2">{{ 'dmarc.ip'|trans }}</th>
            <th class="source" rowspan="2">{{ 'dmarc.reported_by'|trans }}</th>
            <td colspan="3" class="policy-evaluation">{{ 'dmarc.policy_evaluation'|trans }}</td>
        </tr>
        <tr>
            <th class="disposition">{{ 'dmarc.override_reason'|trans }}</th>
            <th class="policy">{{ 'dmarc.dkim'|trans }}</th>
            <th class="policy">{{ 'dmarc.spf'|trans }}</th>
        </tr>
        </thead>
        <tbody>
        {% for record in feedback.overriddenRecords %}
            <tr data-auth-results="<table><thead><tr><th colspan='3'>{{ 'dmarc.auth_results'|trans }}</th></tr></thead><tbody>
            {%- for dkim in record.dkimAuthResults -%}
            <tr><td class='auth-type'>DKIM</td><td class='auth-domain'><strong>{{ dkim.domain }}</strong> {% if dkim.selector is not empty %}({{ dkim.selector }}){% endif %}</td><td class='auth-{{ dkim.result }}'>{{ dkim.result }}</td></tr>
            {%- endfor -%}
            {%- for spf in record.spfAuthResults -%}
            <tr><td class='auth-type'>SPF</td><td class='auth-domain'><strong>{{ spf.domain }}</strong></td><td class='auth-{{ spf.result }}'>{{ spf.result }}</td></tr>
            {%- endfor -%}
            </table>">
                <td class="count">{{ record.count|format_number }}</td>
                <th>{{ record.sourceIp|rich_ip(null, false, false) }}</th>
                <td style="color: gray">{{ record.reporters|join(', ') }}</td>
                <td class="disposition">
                    {% for reason in record.reasons %}
                        {{ reason.type }}: {{ reason.comment }}<br />
                    {% endfor %}
                </td>
                <td class="policy-overriden">{{ record.dkim }}</td>
                <td class="policy-overriden">{{ record.spf }}</td>
            </tr>
        {% endfor %}
        </tbody>
    </table>
    {% endif %}

    <br />
    <br /><br /><br /><br /><br /><br /><br />

    {% include "Pro/DmarcReports/_style.html.twig" %}
{% endif %}
{% endblock %}

{% block javascripts %}
    <script>
        $('table tbody tr').mouseenter(function() {
            if (!$(this).attr('data-auth-results')) return;
            $(this).popover({
                animation: false,
                placement: 'bottom',
                container: 'body',
                html: true,
                //selector: '[rel="popover"]', //Sepcify the selector here
                content: $(this).attr('data-auth-results')
            });
            $(this).popover('show')
        }).mouseleave(function() {
            $(this).popover('destroy')
        });
    </script>
{% endblock %}
